#!/bin/bash
#
#       82 - lnadmin user, backup scripts and administration panel setup
#

echo -e "\n\t# lnadmin user and backup scripts setup #\n"


# User creation
echo "Creant l'usuari lnadmin"
res_value=0
res=$(getent passwd lnadmin || useradd -m -r -s /bin/bash -d /home-local/lnadmin --service files -p $1 lnadmin 2>&1)
if [ ! $? -eq 0 ];then
	echo -e "Error:: No s'ha pogut crear l'usuari lnadmin; $res"
	res_value=1
else
	echo -e "Ok\n"
	echo -e "\n\tSuccess: Usuari lnadmin creat\n"
fi


# Only proceed if lnadmin user is properly created in the system, otherwise abort for security reasons
if [ $res_value -eq 0 ]; then


	# Set up lnadmin login scripts
	if [ ! -e /home-local/lnadmin/.gnome2 ];then
		res=$(mkdir -m 755 /home-local/lnadmin/.gnome2 && chown lnadmin:users /home-local/lnadmin/.gnome2 2>&1)
		if [ ! $? -eq 0 ];then
			echo "Error:: No s'ha pogut crear el fitxer d'arrancada de gnome de l'usuari lnadmin: $res"
		fi
	else
		if [ -e /home-local/lnadmin/session-manual ];then
			res=$(mv /home-local/lnadmin/.gnome2/session-manual /etc/Linkat/backup/lnadmin-session-manual.orig 2>&1)
			if [ ! $? -eq 0 ];then
				echo "Error:: No s'ha pogut fer una copia de seguretat del fitxer session-manual de l'usuari lnadmin; $res"
			fi
		fi
	fi

	res=$(cp /etc/Linkat/data/session-manual.Linkat /home-local/lnadmin/.gnome2/session-manual 2>&1)
	if [ ! $? -eq 0 ];then
		echo "Error:: No s'ha pogut aplicar l'arrancada automàtica de logon scripts del l'usuari lnadmin; $res"
	else
		res=$(chmod 644 /home-local/lnadmin/.gnome2/session-manual && chown lnadmin:users /home-local/lnadmin/.gnome2/session-manual 2>&1)
		if [ ! $? -eq 0 ];then
			echo "Warning:: No s'ha pogut aplicar correctament l'arrancada automàtica de logon scripts del l'usuari lnadmin; $res"
		else
			echo -e "\n\t Linkat: Canvis aplicats per l'execució automàtica de logon scripts del l'usuari lnadmin\n"
		fi
	fi

	# xhost + for lnadmin X session
	echo -e "Autoritzant accés local a l'escriptori de lnadmin"
	res=$(mkdir -p /home-local/lnadmin/.config/autostart/ && chown lnadmin:users /home-local/lnadmin/.config/ && chown lnadmin:users /home-local/lnadmin/.config/autostart/ 2>&1)
	if [ ! $? -eq 0 ];then
		echo -e "Error:: No s'ha pogut crear correctament el directori autostart de lnadmin; $res"
	else
		res=$(cp /etc/Linkat/data/xhost.desktop /home-local/lnadmin/.config/autostart/ && chown lnadmin:users /home-local/lnadmin/.config/autostart/xhost.desktop && chmod 644 /home-local/lnadmin/.config/autostart/xhost.desktop 2>&1)
		if [ ! $? -eq 0 ];then
			echo -e "Error:: No s'ha pogut autoritzar l'accés de root a les X de lnadmin; $res"
		else
			echo -e "Ok\n"
			echo -e "\n\tSuccess: Autoritzat accés local a l'escriptori de lnadmin\n"
		fi
	fi



	# Policykit permissions setup
	echo -e "Establint permisos de policykit per la impressora"
	res=$(polkit-auth --user lnadmin --grant org.opensuse.cupspkhelper.mechanism.server-settings 2>&1)
	if [ ! $? -eq 0 ];then
		echo -e "Error:: No s'ha pogut autoritzar lnadmin a canviar server-settings; $res"
	else
		echo -e "Ok\n"
		echo -e "\n\tSuccess: lnadmin autoritzat a canviar la configuració del CUPS\n"
	fi
	
	res=$(polkit-auth --user lnadmin --grant org.opensuse.cupspkhelper.mechanism.printeraddremove 2>&1)
	if [ ! $? -eq 0 ];then
		echo -e "Error:: No s'ha pogut autoritzar lnadmin a afegir i eliminar impressores; $res"
	else
		echo -e "Ok\n"
		echo -e "\n\tSuccess: lnadmin autoritzat a afegir i eliminar impressores\n"
	fi
	
	res=$(polkit-auth --user lnadmin --grant org.opensuse.cupspkhelper.mechanism.printer-set-default 2>&1)
	if [ ! $? -eq 0 ];then
		echo -e "Error:: No s'ha pogut autoritzar lnadmin a canviar la impressora per defecte; $res"
	else
		echo -e "Ok\n"
		echo -e "\n\tSuccess: lnadmin autoritzat a canviar la impressora per defecte\n"
	fi
	
	res=$(polkit-auth --user lnadmin --grant org.opensuse.cupspkhelper.mechanism.printer-remote-edit 2>&1)
	if [ ! $? -eq 0 ];then
		echo -e "Error:: No s'ha pogut autoritzar lnadmin a modificar una impressora remota; $res"
	else
		echo -e "Ok\n"
		echo -e "\n\tSuccess: lnadmin autoritzat a modificar una impressora remota\n"
	fi
	
	
	res=$(polkit-auth --user lnadmin --grant org.opensuse.cupspkhelper.mechanism.printer-local-edit 2>&1)
	if [ ! $? -eq 0 ];then
		echo -e "Error:: No s'ha pogut autoritzar lnadmin a canviar les impressores locals; $res"
	else
		echo -e "Ok\n"
		echo -e "\n\tSuccess: lnadmin autoritzat a canviar les impressores locals\n"
	fi
	
	res=$(polkit-auth --user lnadmin --grant org.opensuse.cupspkhelper.mechanism.printer-enable 2>&1)
	if [ ! $? -eq 0 ];then
		echo -e "Error:: No s'ha pogut autoritzar lnadmin a habilitar impressores; $res"
	else
		echo -e "Ok\n"
		echo -e "\n\tSuccess: lnadmin autoritzat a habilitar i deshabilitar impressores\n"
	fi
	
	res=$(polkit-auth --user lnadmin --grant org.opensuse.cupspkhelper.mechanism.class-edit 2>&1)
	if [ ! $? -eq 0 ];then
		echo -e "Error:: No s'ha pogut autoritzar lnadmin a editar classes d'impressió; $res"
	else
		echo -e "Ok\n"
		echo -e "\n\tSuccess: lnadmin autoritzat a canviar classes d'impressió\n"
	fi
	
	
	
	# Clock applet permissions
	echo -e "Autoritzant lnadmin a canviar l'hora i fus horari del sistema"
	res=$(polkit-auth --user lnadmin --grant org.gnome.clockapplet.mechanism.settimezone 2>&1)
	if [ ! $? -eq 0 ];then
		echo -e "Error:: No s'ha pogut autoritzar lnadmin a canviar el fus horari del sistema; $res"
	else
		echo -e "Ok\n"
		echo -e "\n\tSuccess: lnadmin autoritzat a canviar el fus horari del sistema\n"
	fi
	
	res=$(polkit-auth --user lnadmin --grant org.gnome.clockapplet.mechanism.settime 2>&1)
	if [ ! $? -eq 0 ];then
		echo -e "Error:: No s'ha pogut autoritzar lnadmin a canviar l'hora del sistema; $res"
	else
		echo -e "Ok\n"
		echo -e "\n\tSuccess: lnadmin autoritzat a canviar l'hora del sistema (settime)\n"
	fi
	
	res=$(polkit-auth --user lnadmin --grant org.gnome.clockapplet.mechanism.configurehwclock 2>&1)
	if [ ! $? -eq 0 ];then
		echo -e "Error:: No s'ha pogut autoritzar lnadmin per canviar el rellotge del sistema; $res"
	else
		echo -e "Ok\n"
		echo -e "\n\tSuccess: lnadmin autoritzat a canviar l'hora del sistema (hwclock)\n"
	fi
	
	
	# Package updates
	echo -e "Autoritzant lnadmin a actualitzar el sistema"
	res=$(polkit-auth --user lnadmin --grant org.freedesktop.packagekit.system-update 2>&1)
	if [ ! $? -eq 0 ];then
		echo -e "Error:: No s'ha pogut autoritzar lnadmin per actualitzar el sistema; $res"
	else
		echo -e "Ok\n"
		echo -e "\n\tSuccess: lnadmin autoritzat (system-update)\n"
	fi
	
	echo -e "Autoritzant lnadmin a confiar en claus de firma"
	res=$(polkit-auth --user lnadmin --grant org.freedesktop.packagekit.system-trust-signing-key 2>&1)
	if [ ! $? -eq 0 ];then
		echo -e "Error:: No s'ha pogut autoritzar a lnadmin; $res"
	else
		echo -e "Ok\n"
		echo -e "\n\tSuccess: lnadmin autoritzat (system-trust-signing-key)\n"
	fi
	
	echo -e "Autoritzant lnadmin a configurar el proxy de xarxa"
	res=$(polkit-auth --user lnadmin --grant org.freedesktop.packagekit.system-network-proxy-configure 2>&1)
	if [ ! $? -eq 0 ];then
		echo -e "Error:: No s'ha pogut autoritzar a lnadmin; $res"
	else
		echo -e "Ok\n"
		echo -e "\n\tSuccess: lnadmin autoritzat (system-network-proxy-configure)\n"
	fi
	
	echo -e "Autoritzant lnadmin a acceptar llicències d'un nou paquet"
	res=$(polkit-auth --user lnadmin --grant org.freedesktop.packagekit.package-eula-accept 2>&1)
	if [ ! $? -eq 0 ];then
		echo -e "Error:: No s'ha pogut autoritzar a lnadmin; $res"
	else
		echo -e "Ok\n"
		echo -e "\n\tSuccess: lnadmin autoritzat (package-eula-accept)\n"
	fi
	
	
	
	# Desktop icons setup
	echo -e "Instal·lant icones d'administració del client"
	res=$(mkdir -p /home-local/lnadmin/Desktop && chown lnadmin:users /home-local/lnadmin/Desktop && cd /home-local/lnadmin/Desktop && tar -zxvf /etc/Linkat/data/eines_lnadmin_client.tar.gz && chown -R root:root /home-local/lnadmin/Desktop/Eines\ d\'administració 2>&1)
	if [ ! $? -eq 0 ];then
		echo -e "Error:: No s'han pogut extreure les icones d'administració del client; $res"
	else
		echo -e "Ok\n"
		echo -e "\n\tSuccess: Icones de les eines d'administració del client extretes correctament\n"
	fi
	
fi	
